summaryrefslogtreecommitdiff
path: root/vm_core.h
diff options
context:
space:
mode:
authorTakashi Kokubun <takashikkbn@gmail.com>2023-08-08 16:06:22 -0700
committerGitHub <noreply@github.com>2023-08-08 16:06:22 -0700
commitcd8d20cd1fbcf9bf9d438b306beb65b2417fcc04 (patch)
treee278f50d1819908f6bc8b558c074dfde1880e762 /vm_core.h
parent74b9c7d2079ce2b762bc555f491d00f863fcf94d (diff)
YJIT: Compile exception handlers (#8171)
Co-authored-by: Maxime Chevalier-Boisvert <maximechevalierb@gmail.com>
Notes
Notes: Merged-By: k0kubun <takashikkbn@gmail.com>
Diffstat (limited to 'vm_core.h')
-rw-r--r--vm_core.h15
1 files changed, 11 insertions, 4 deletions
diff --git a/vm_core.h b/vm_core.h
index 77861372ff..d9d926d2ad 100644
--- a/vm_core.h
+++ b/vm_core.h
@@ -503,10 +503,17 @@ struct rb_iseq_constant_body {
const rb_iseq_t *mandatory_only_iseq;
#if USE_RJIT || USE_YJIT
- // Function pointer for JIT code
- rb_jit_func_t jit_func;
- // Number of total calls with jit_exec()
- long unsigned total_calls;
+ // Function pointer for JIT code on jit_exec()
+ rb_jit_func_t jit_entry;
+ // Number of calls on jit_exec()
+ long unsigned jit_entry_calls;
+#endif
+
+#if USE_YJIT
+ // Function pointer for JIT code on jit_exec_exception()
+ rb_jit_func_t jit_exception;
+ // Number of calls on jit_exec_exception()
+ long unsigned jit_exception_calls;
#endif
#if USE_RJIT